@@ -92,6 +92,7 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
     VSTREAM *bounce;
     int     notify_mask = name_mask(VAR_NOTIFY_CLASSES, mail_error_masks,
 				    var_notify_classes);
+    VSTRING *new_id = vstring_alloc(10);
     char   *postmaster;
     int     count;
 
@@ -164,7 +165,8 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
 	    if ((bounce = post_mail_fopen_nowait(mail_addr_double_bounce(),
 						 postmaster,
 						 CLEANUP_FLAG_MASK_INTERNAL,
-						 NULL_TRACE_FLAGS)) != 0) {
+						 NULL_TRACE_FLAGS,
+						 new_id)) != 0) {
 
 		/*
 		 * Double bounce to Postmaster. This is the last opportunity
@@ -182,6 +184,9 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
 					     DSN_NOTIFY_OVERRIDE) > 0) {
 		    bounce_original(bounce, bounce_info, DSN_RET_FULL);
 		    bounce_status = post_mail_fclose(bounce);
+		    if (bounce_status == 0)
+			msg_info("%s: postmaster delay notification: %s",
+				 queue_id, STR(new_id));
 		} else {
 		    (void) vstream_fclose(bounce);
 		    if (count == 0)
@@ -198,7 +203,8 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
     else {
 	if ((bounce = post_mail_fopen_nowait(NULL_SENDER, recipient,
 					     CLEANUP_FLAG_MASK_INTERNAL,
-					     NULL_TRACE_FLAGS)) != 0) {
+					     NULL_TRACE_FLAGS,
+					     new_id)) != 0) {
 
 	    /*
 	     * Send the bounce message header, some boilerplate text that
@@ -216,6 +222,9 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
 					 DSN_NOTIFY_DELAY) > 0) {
 		bounce_original(bounce, bounce_info, DSN_RET_HDRS);
 		bounce_status = post_mail_fclose(bounce);
+		if (bounce_status == 0)
+		    msg_info("%s: sender delay notification: %s",
+			     queue_id, STR(new_id));
 	    } else {
 		(void) vstream_fclose(bounce);
 		if (count == 0)
@@ -244,7 +253,8 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
 	    if ((bounce = post_mail_fopen_nowait(mail_addr_double_bounce(),
 						 postmaster,
 						 CLEANUP_FLAG_MASK_INTERNAL,
-						 NULL_TRACE_FLAGS)) != 0) {
+						 NULL_TRACE_FLAGS,
+						 new_id)) != 0) {
 		count = -1;
 		if (bounce_header(bounce, bounce_info, postmaster,
 				  POSTMASTER_COPY) == 0
@@ -255,6 +265,9 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
 					     DSN_NOTIFY_OVERRIDE) > 0) {
 		    bounce_original(bounce, bounce_info, DSN_RET_HDRS);
 		    postmaster_status = post_mail_fclose(bounce);
+		    if (postmaster_status == 0)
+			msg_info("%s: postmaster delay notification: %s",
+				 queue_id, STR(new_id));
 		} else {
 		    (void) vstream_fclose(bounce);
 		    if (count == 0)
@@ -262,8 +275,8 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
 		}
 	    }
 	    if (postmaster_status)
-		msg_warn("postmaster notice failed while bouncing to %s",
-			 recipient);
+		msg_warn("%s: postmaster notice failed while warning %s",
+			 queue_id, recipient);
 	}
     }
 
@@ -271,6 +284,7 @@ int     bounce_warn_service(int unused_flags, char *service, char *queue_name,
      * Cleanup.
      */
     bounce_mail_free(bounce_info);
+    vstring_free(new_id);
 
     return (bounce_status);
 }
