@@ -147,7 +147,6 @@
 
 #include <sys_defs.h>
 #include <sys/stat.h>
-#include <sys/time.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <utime.h>
@@ -268,7 +267,7 @@ static int flush_policy_ok(const char *site)
 
 static int flush_add_service(const char *site, const char *queue_id)
 {
-    const char *myname = "flush_add_service";
+    char   *myname = "flush_add_service";
     VSTRING *site_path;
     int     status;
 
@@ -295,7 +294,7 @@ static int flush_add_service(const char *site, const char *queue_id)
 
 static int flush_add_path(const char *path, const char *queue_id)
 {
-    const char *myname = "flush_add_path";
+    char   *myname = "flush_add_path";
     VSTREAM *log;
 
     /*
@@ -344,7 +343,7 @@ static int flush_add_path(const char *path, const char *queue_id)
 
 static int flush_send_service(const char *site, int how)
 {
-    const char *myname = "flush_send_service";
+    char   *myname = "flush_send_service";
     VSTRING *site_path;
     int     status;
 
@@ -480,11 +479,6 @@ static int flush_send_path(const char *path, int how)
     if (count > 0 && ftruncate(vstream_fileno(log), (off_t) 0) < 0)
 	msg_fatal("%s: truncate fast flush logfile %s: %m", myname, path);
 
-    /*
-     * Workaround for noatime mounts. Use futimes() if available.
-     */
-    (void) utimes(VSTREAM_PATH(log), (struct timeval *) 0);
-
     /*
      * Request delivery and clean up.
      */
@@ -509,7 +503,7 @@ static int flush_send_path(const char *path, int how)
 
 static int flush_refresh_service(int max_age)
 {
-    const char *myname = "flush_refresh_service";
+    char   *myname = "flush_refresh_service";
     SCAN_DIR *scan;
     char   *site_path;
     struct stat st;
